==> org.eclipse.papyrusrt.umlrt.tooling.tables.source_0.9.0.201703230413.jar: org/eclipse/papyrusrt/umlrt/tooling/tables/manager/cell/TriggerProtocolMessageCellManager.java <==
/*******************************************************************************
 * Copyright (c) 2016 Zeligsoft (2009) Limited and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *   Young-Soo Roh - Initial API and implementation
 *******************************************************************************/

package org.eclipse.papyrusrt.umlrt.tooling.tables.manager.cell;

import org.eclipse.papyrus.infra.nattable.utils.AxisUtils;
import org.eclipse.papyrus.uml.nattable.manager.cell.UMLFeatureCellManager;
import org.eclipse.uml2.uml.Trigger;
import org.eclipse.uml2.uml.UMLPackage;

/**
 * Trigger port cell manager.
 * 
 * @author ysroh
 *
 */
public class TriggerProtocolMessageCellManager extends UMLFeatureCellManager {

	/**
	 * @see org.eclipse.papyrus.uml.nattable.manager.cell.UMLFeatureCellManager#handles(java.lang.Object, java.lang.Object)
	 *
	 * @param columnElement
	 * @param rowElement
	 * @return
	 */
	@Override
	public boolean handles(Object columnElement, Object rowElement) {
		boolean result = super.handles(columnElement, rowElement);
		if (result) {
			final Object row = AxisUtils.getRepresentedElement(rowElement);
			Object column = AxisUtils.getRepresentedElement(columnElement);
			if (!(row instanceof Trigger) || !UMLPackage.Literals.TRIGGER__EVENT.equals(column)) {
				result = false;
			}
		}
		return result;
	}

	/**
	 * @see org.eclipse.papyrus.infra.emf.nattable.manager.cell.EMFFeatureValueCellManager#isCellEditable(java.lang.Object, java.lang.Object)
	 *
	 * @param columnElement
	 * @param rowElement
	 * @return
	 */
	@Override
	public boolean isCellEditable(Object columnElement, Object rowElement) {
		return false;
	}
}

==> org.eclipse.papyrusrt.umlrt.tooling.tables.source_1.0.0.201707181457.jar: org/eclipse/papyrusrt/umlrt/tooling/tables/manager/cell/TriggerProtocolMessageCellManager.java <==
/*******************************************************************************
 * Copyright (c) 2016, 2017 Zeligsoft (2009) Limited, Christian W. Damus, and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *   Young-Soo Roh - Initial API and implementation
 *   Christian W. Damus - bug 514322
 *******************************************************************************/

package org.eclipse.papyrusrt.umlrt.tooling.tables.manager.cell;

import org.eclipse.papyrus.infra.nattable.manager.table.INattableModelManager;
import org.eclipse.papyrus.infra.nattable.utils.AxisUtils;
import org.eclipse.papyrus.uml.nattable.manager.cell.UMLFeatureCellManager;
import org.eclipse.uml2.uml.Trigger;
import org.eclipse.uml2.uml.UMLPackage;

/**
 * Trigger port cell manager.
 * 
 * @author ysroh
 *
 */
public class TriggerProtocolMessageCellManager extends UMLFeatureCellManager {

	@Override
	public boolean handles(Object columnElement, Object rowElement, INattableModelManager tableManager) {
		boolean result = super.handles(columnElement, rowElement, tableManager);
		if (result) {
			final Object row = AxisUtils.getRepresentedElement(rowElement);
			Object column = AxisUtils.getRepresentedElement(columnElement);
			if (!(row instanceof Trigger) || !UMLPackage.Literals.TRIGGER__EVENT.equals(column)) {
				result = false;
			}
		}
		return result;
	}

	@Override
	public boolean isCellEditable(Object columnElement, Object rowElement, INattableModelManager tableManager) {
		return false;
	}
}
